# Richard Hendricks

- richard.hendriks@mail.com
- (912) 555-4321
- richardhendricks.example.com
- San Francisco, CA

CEO and Software Engineer with knowledge of applied information theory, including optimizing lossless compression schema of both the length-limited and adaptive variants.

## Experience

### CEO/President, Pied Piper Dec 2013 – Dec 2014

Pied Piper is a multi-platform technology based on a proprietary universal compression algorithm that has consistently fielded high Weisman Scores™ that are not merely competitive, but approach the theoretical limit of lossless compression.

- Build an algorithm for artist to detect if their music was violating copyright infringement laws
- Successfully won Techcrunch Disrupt
- Optimized an algorithm that holds the current world record for Weisman Scores

### Teacher, CoderDojo July 2013 – Dec 2013

Global movement of free coding clubs for young people.

- Awarded ‘Teacher of the Month’

## Projects

### Miss Direction Aug 2016

A mapping engine that misguides you:

- Won award at AIHacks 2016
- Built by all women team of newbie programmers
- Using modern technologies such as GoogleMaps, Chrome Extension and Javascript

## Education

### University of Oklahoma, BA Information Technology 2011 – 2014

- GPA 4.0
- DB1101 - Basic SQL
- CS2011 - Java Introduction

## Skills

- Web development: HTML, CSS, JavaScript
- Compression: Mpeg, MP4, GIF